==> hs-uulib-0.9.5_1.tbz: lib/uulib-0.9.5/register.sh <==
#!/bin/sh

echo 'name: uulib
version: 0.9.5
license: LGPL
copyright: Universiteit Utrecht
maintainer: Arie Middelkoop <ariem@cs.uu.nl>
stability: Stable
homepage: http://www.cs.uu.nl/wiki/HUT/WebHome
package-url:
description: Fast Parser Combinators and Pretty Printing Combinators
category: Parsing
author:
exposed: True
exposed-modules: UU.Parsing.CharParser UU.Parsing.Derived
                 UU.Parsing.Interface UU.Parsing.MachineInterface UU.Parsing.Merge
                 UU.Parsing.Offside UU.Parsing.Perms UU.Parsing.StateParser
                 UU.Parsing UU.DData.IntBag UU.DData.Map UU.DData.MultiSet
                 UU.DData.Queue UU.DData.Scc UU.DData.Seq UU.DData.Set UU.PPrint
                 UU.Pretty.Ext UU.Pretty UU.Scanner.GenToken UU.Scanner.GenTokenOrd
                 UU.Scanner.GenTokenParser UU.Scanner.GenTokenSymbol
                 UU.Scanner.Position UU.Scanner.Scanner UU.Scanner.Token
                 UU.Scanner.TokenParser UU.Scanner.TokenShow UU.Scanner
                 UU.Util.BinaryTrees UU.Util.PermTree UU.Util.Utils UU.Pretty.Basic
                 UU.Parsing.Machine UU.DData.IntMap UU.DData.IntSet
hidden-modules:
import-dirs: /usr/local/lib/uulib-0.9.5/ghc-6.8.3
library-dirs: /usr/local/lib/uulib-0.9.5/ghc-6.8.3
hs-libraries: HSuulib-0.9.5
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-3.0.2.0 haskell98-1.0.1.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/uulib-0.9.5/html/uulib.haddock
haddock-html: /usr/local/share/doc/uulib-0.9.5/html' | /usr/local/bin/ghc-pkg update -

==> hs-uulib-0.9.10.tbz: lib/uulib-0.9.10/register.sh <==
#!/bin/sh

echo 'name: uulib
version: 0.9.10
license: LGPL
copyright: Universiteit Utrecht
maintainer: Arie Middelkoop <ariem@cs.uu.nl>
stability: Stable
homepage: http://www.cs.uu.nl/wiki/HUT/WebHome
package-url:
description: Fast Parser Combinators and Pretty Printing Combinators
category: Parsing
author:
exposed: True
exposed-modules: UU.Parsing.CharParser UU.Parsing.Derived
                 UU.Parsing.Interface UU.Parsing.MachineInterface UU.Parsing.Merge
                 UU.Parsing.Offside UU.Parsing.Perms UU.Parsing.StateParser
                 UU.Parsing UU.DData.IntBag UU.DData.Map UU.DData.MultiSet
                 UU.DData.Queue UU.DData.Scc UU.DData.Seq UU.DData.Set UU.PPrint
                 UU.Pretty.Ext UU.Pretty UU.Scanner.GenToken UU.Scanner.GenTokenOrd
                 UU.Scanner.GenTokenParser UU.Scanner.GenTokenSymbol
                 UU.Scanner.Position UU.Scanner.Scanner UU.Scanner.Token
                 UU.Scanner.TokenParser UU.Scanner.TokenShow UU.Scanner
                 UU.Util.BinaryTrees UU.Util.PermTree UU.Util.Utils UU.Pretty.Basic
                 UU.Parsing.Machine UU.DData.IntMap UU.DData.IntSet
hidden-modules:
import-dirs: /usr/local/lib/uulib-0.9.10/ghc-6.10.4
library-dirs: /usr/local/lib/uulib-0.9.10/ghc-6.10.4
hs-libraries: HSuulib-0.9.10
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.1.0.0 ghc-prim-0.1.0.0 haskell98-1.0.1.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/uulib-0.9.10/html/uulib.haddock
haddock-html: /usr/local/share/doc/uulib-0.9.10/html' | /usr/local/bin/ghc-pkg update -
